kerasadf.layers.pooling.AveragePooling2D
========================================

.. currentmodule:: kerasadf.layers.pooling

.. autoclass:: AveragePooling2D
   :members:
   :undoc-members:
   :no-inherited-members:
   :show-inheritance:
